diff -ur gst-old/ext/neon/gstneonhttpsrc.c gst-plugins-bad-1.4.3/ext/neon/gstneonhttpsrc.c
--- gst-old/ext/neon/gstneonhttpsrc.c	2014-07-21 15:25:53.000000000 +0700
+++ gst-plugins-bad-1.4.3/ext/neon/gstneonhttpsrc.c	2014-10-07 12:12:14.586436513 +0700
@@ -54,6 +54,7 @@
 #define DEFAULT_USER_AGENT           "GStreamer neonhttpsrc"
 #define DEFAULT_AUTOMATIC_REDIRECT   TRUE
-#define DEFAULT_ACCEPT_SELF_SIGNED   FALSE
+#define DEFAULT_ACCEPT_SELF_SIGNED   TRUE 
+#define DEFAULT_IGNORE_SSL_ERRORS    TRUE
 #define DEFAULT_NEON_HTTP_DEBUG      FALSE
 #define DEFAULT_CONNECT_TIMEOUT      0
 #define DEFAULT_READ_TIMEOUT         0
@@ -68,6 +69,7 @@
   PROP_COOKIES,
   PROP_AUTOMATIC_REDIRECT,
   PROP_ACCEPT_SELF_SIGNED,
+  PROP_IGNORE_SSL_ERRORS,
   PROP_CONNECT_TIMEOUT,
   PROP_READ_TIMEOUT,
 #ifndef GST_DISABLE_GST_DEBUG
@@ -164,6 +166,13 @@
           DEFAULT_ACCEPT_SELF_SIGNED,
           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
+  g_object_class_install_property
+      (gobject_class, PROP_IGNORE_SSL_ERRORS,
+      g_param_spec_boolean ("ignore-ssl-errors", "ignore-ssl-errors",
+          "Ignore all SSL certificate errors",
+          DEFAULT_IGNORE_SSL_ERRORS,
+          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
+
   g_object_class_install_property (gobject_class, PROP_CONNECT_TIMEOUT,
       g_param_spec_uint ("connect-timeout", "connect-timeout",
           "Value in seconds to timeout a blocking connection (0 = default).", 0,
@@ -223,6 +232,7 @@
   src->user_agent = g_strdup (DEFAULT_USER_AGENT);
   src->automatic_redirect = DEFAULT_AUTOMATIC_REDIRECT;
   src->accept_self_signed = DEFAULT_ACCEPT_SELF_SIGNED;
+  src->ignore_ssl_errors = DEFAULT_IGNORE_SSL_ERRORS;
   src->connect_timeout = DEFAULT_CONNECT_TIMEOUT;
   src->read_timeout = DEFAULT_READ_TIMEOUT;
   src->iradio_mode = DEFAULT_IRADIO_MODE;
@@ -336,6 +346,9 @@
     case PROP_ACCEPT_SELF_SIGNED:
       src->accept_self_signed = g_value_get_boolean (value);
       break;
+    case PROP_IGNORE_SSL_ERRORS:
+      src->ignore_ssl_errors = g_value_get_boolean (value);
+      break;      
     case PROP_CONNECT_TIMEOUT:
       src->connect_timeout = g_value_get_uint (value);
       break;
@@ -407,6 +420,9 @@
     case PROP_ACCEPT_SELF_SIGNED:
       g_value_set_boolean (value, neonhttpsrc->accept_self_signed);
       break;
+    case PROP_IGNORE_SSL_ERRORS:
+      g_value_set_boolean (value, neonhttpsrc->ignore_ssl_errors);
+      break;      
     case PROP_CONNECT_TIMEOUT:
       g_value_set_uint (value, neonhttpsrc->connect_timeout);
       break;
@@ -806,6 +822,12 @@
     failures &= ~NE_SSL_UNTRUSTED;
   }
 
+  if (src->ignore_ssl_errors && failures) {
+    GST_ELEMENT_INFO (src, RESOURCE, READ,
+        (NULL), ("Ignoring all SSL errors: %d", failures));
+    failures = 0;
+  }
+
   if (failures & NE_SSL_NOTYETVALID)
     GST_ELEMENT_ERROR (src, RESOURCE, READ,
         (NULL), ("Server certificate not valid yet"));
diff -ur gst-old/ext/neon/gstneonhttpsrc.h gst-plugins-bad-1.4.3/ext/neon/gstneonhttpsrc.h
--- gst-old/ext/neon/gstneonhttpsrc.h	2014-07-21 15:25:53.000000000 +0700
+++ gst-plugins-bad-1.4.3/ext/neon/gstneonhttpsrc.h	2014-10-07 12:11:46.966438299 +0700
@@ -70,6 +70,9 @@
   /* accept self-signed certificates */
   gboolean accept_self_signed;
 
+  /* ignore all SSL errors  */
+  gboolean ignore_ssl_errors;
+
   gint64 read_position;
   gboolean seekable;
 
